# Contributing

Welcome to Blueprint! We're thrilled that you'd like to contribute. Your help is essential for making it better.

## Getting Started

Before you start contributing, please make sure you have read and understood our [Code of Conduct](.github/CODE_OF_CONDUCT.md).

1. Fork the Repository

First, fork the [repository](https://github.com/giacomoguidotto/blueprint) to your own GitHub account. This will create a copy of the project under your account.

2. Clone the Repository

   ```sh
   git clone https://github.com/giacomoguidotto/blueprint
   ```

3. Navigate to the project directory 📁

   ```sh
   cd blueprint
   ```

4. Create a new branch for your feature or bug fix:

   ```sh
   git checkout -b feat/feature-branch
   ```

5. Make your changes and commit them following the [Conventional Commits](https://www.conventionalcommits.org/en/v1.0.0/) specification:

   ```sh
   git add .
   git commit -m "feat: description of your changes"
   ```

6. Push your changes to your fork:

   ```sh
   git push origin feature-branch
   ```

7. Finally Click on Create Pull request to contribute on this repository.
